@@ -1,6 +1,12 @@
 #include <R.h>
 #include <Rdefines.h>
 
+#ifndef  R_INTERNALS_H_
+#include <Rinternals.h>
+#endif
+
+
+
 /*============================================================================
   global R variables 
 ============================================================================*/
@@ -8,7 +14,7 @@
 double *timesteps; /* see also: R_init_deSolve.c */
 
 SEXP YOUT, YOUT2, ISTATE, RWORK, IROOT;    /* returned to R */
-SEXP Time, Y, YPRIME , Rin;
+SEXP Y, YPRIME , Rin;
 
 int     n_eq; 
 
